export type Image = {
  src: string;
  alt?: string;
  caption?: string;
};

export type Link = {
  text: string;
  href: string;
};

export type Hero = {
  title?: string;
  text?: string;
  image?: Image;
  actions?: Link[];
};

export type Subscribe = {
  title?: string;
  text?: string;
  formUrl: string;
};

export type SiteConfig = {
  website: string;
  logo?: Image;
  title: string;
  subtitle?: string;
  description: string;
  image?: Image;
  headerNavLinks?: Link[];
  footerNavLinks?: Link[];
  socialLinks?: Link[];
  hero?: Hero;
  subscribe?: Subscribe;
  postsPerPage?: number;
  projectsPerPage?: number;
};

const siteConfig: SiteConfig = {
  website: "https://readings.tiff.ws",
  title: "tiff on books",
  subtitle: "notes from books i've read",
  description: "from the brain of tiff on software",
  // image: {
  //     src: '/dante-preview.jpg',
  //     alt: 'Dante - Astro.js and Tailwind CSS theme'
  // },
  headerNavLinks: [
    {
      text: "Home",
      href: "/",
    },
    {
      text: "Blog",
      href: "/blog",
    },
    {
      text: "Tags",
      href: "/tags",
    },
  ],
  footerNavLinks: [
    {
      text: "About",
      href: "/about",
    },
  ],
  socialLinks: [
    {
      text: "Matrix",
      href: "https://matrix.to/#/@100pdatcat:matrix.org",
    },
    {
      text: "Signal",
      href:
        "https://signal.me/#eu/Bdd-Fbkm5vTYvnUtpmCVtw-gGndYPlBHF_O4XWypX-JYwXf0r7dIpIdbWa2QnN6F",
    },
    {
      text: "Email",
      href: "mailto:hithere@tiff.run",
    },
  ],
  hero: {
    title: "books. they're what's on tap here.",
    text:
      "I'm **tiff**, a dev during the day, mad electronics scientist at night, and a Linux enthusiast who sometimes writes but who wants to read more books. Here's where I'll dump my notes on the books I've read.",
  },
  postsPerPage: 8,
  projectsPerPage: 8,
};

export default siteConfig;
